# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .shared import References as References, ResponseWrapper as ResponseWrapper
from .stop_retrieve_response import StopRetrieveResponse as StopRetrieveResponse
from .trip_retrieve_response import TripRetrieveResponse as TripRetrieveResponse
from .route_retrieve_response import RouteRetrieveResponse as RouteRetrieveResponse
from .agency_retrieve_response import AgencyRetrieveResponse as AgencyRetrieveResponse
from .config_retrieve_response import ConfigRetrieveResponse as ConfigRetrieveResponse
from .stops_for_route_list_params import StopsForRouteListParams as StopsForRouteListParams
from .trip_detail_retrieve_params import TripDetailRetrieveParams as TripDetailRetrieveParams
from .stops_for_route_list_response import StopsForRouteListResponse as StopsForRouteListResponse
from .trip_detail_retrieve_response import TripDetailRetrieveResponse as TripDetailRetrieveResponse
from .current_time_retrieve_response import CurrentTimeRetrieveResponse as CurrentTimeRetrieveResponse
from .trip_for_vehicle_retrieve_params import TripForVehicleRetrieveParams as TripForVehicleRetrieveParams
from .arrival_and_departure_list_params import ArrivalAndDepartureListParams as ArrivalAndDepartureListParams
from .stops_for_location_retrieve_params import StopsForLocationRetrieveParams as StopsForLocationRetrieveParams
from .trip_for_vehicle_retrieve_response import TripForVehicleRetrieveResponse as TripForVehicleRetrieveResponse
from .trips_for_location_retrieve_params import TripsForLocationRetrieveParams as TripsForLocationRetrieveParams
from .arrival_and_departure_list_response import ArrivalAndDepartureListResponse as ArrivalAndDepartureListResponse
from .stops_for_location_retrieve_response import StopsForLocationRetrieveResponse as StopsForLocationRetrieveResponse
from .trips_for_location_retrieve_response import TripsForLocationRetrieveResponse as TripsForLocationRetrieveResponse
from .arrival_and_departure_retrieve_params import (
    ArrivalAndDepartureRetrieveParams as ArrivalAndDepartureRetrieveParams,
)
from .arrival_and_departure_retrieve_response import (
    ArrivalAndDepartureRetrieveResponse as ArrivalAndDepartureRetrieveResponse,
)
from .agencies_with_coverage_retrieve_response import (
    AgenciesWithCoverageRetrieveResponse as AgenciesWithCoverageRetrieveResponse,
)





import onebusaway


def main_sync() -> None:
    client = onebusaway.OnebusawaySDK(api_key="TEST")
    stop = client.stop.retrieve("1_75403")

    if stop.data and stop.data.entry:
        print(stop.data.entry)
    else:
        print("stop not found")

if __name__ == "__main__":
    main_sync()





import onebusaway


def main_sync() -> None:
    client = onebusaway.OnebusawaySDK(api_key="TEST")
    agency = client.agency.retrieve("1")

    if agency.data and agency.data.entry:
        print(agency.data.entry)
    else:
        print("Agency data or entry is None.")

if __name__ == "__main__":
    main_sync()



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["StopsForLocationRetrieveParams"]


class StopsForLocationRetrieveParams(TypedDict, total=False):
    key: Required[str]

    lat: float

    lon: float



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = [
    "TripsForLocationRetrieveResponse",
    "TripsForLocationRetrieveResponseData",
    "TripsForLocationRetrieveResponseDataList",
]


class TripsForLocationRetrieveResponseDataList(BaseModel):
    frequency: Optional[str] = None

    service_date: Optional[int] = FieldInfo(alias="serviceDate", default=None)

    situation_ids: Optional[List[str]] = FieldInfo(alias="situationIds", default=None)

    trip_id: Optional[str] = FieldInfo(alias="tripId", default=None)


class TripsForLocationRetrieveResponseData(BaseModel):
    limit_exceeded: Optional[bool] = FieldInfo(alias="limitExceeded", default=None)
    """Indicates if the limit of trips has been exceeded"""

    list: Optional[List[TripsForLocationRetrieveResponseDataList]] = None

    out_of_range: Optional[bool] = FieldInfo(alias="outOfRange", default=None)
    """Indicates if the search location is out of range"""

    references: Optional[References] = None


class TripsForLocationRetrieveResponse(ResponseWrapper):
    data: Optional[TripsForLocationRetrieveResponseData] = None
